/*
Index Related DMV
Database Scope
Returns size and fragmentation information for the data and indexes of the specified table or view. 
Replaces the DBCC SHOWCONTIG statement
*/

SELECT TOP 50 OBJECT_NAME(s.[object_id]) AS tableName
		,i.[name] AS indexName
		,s.index_type_desc AS indexType
		,s.partition_number
		,s.page_count AS numberOfPages		
		,s.fragment_count AS fragmentCount		
		,ROUND(avg_fragmentation_in_percent,2) AS fragmentationPercent
		,ROUND(s.avg_fragment_size_in_pages, 2) AS averageFragmentationInPages	--page_count/fragment_count
FROM sys.dm_db_index_physical_stats(db_id(),null, null, null, null) s
	INNER JOIN sys.indexes i ON s.[object_id] = i.[object_id] AND s.index_id = i.index_id 
WHERE s.database_id = DB_ID() 
	AND i.name IS NOT NULL	--Ignore HEAP indexes
    AND OBJECTPROPERTY(s.[object_id], 'IsMsShipped') = 0
ORDER BY fragmentationPercent DESC;