/*
Index related
Database scope
Returns counts of different types of index operations and the time each type of operation was last performed. 
*/

SELECT TOP 50 OBJECT_NAME(s.[object_id]) AS objectName
	,i.[name] AS indexName
	,(s.user_seeks + s.user_scans + s.user_lookups) AS Usage
FROM sys.dm_db_index_usage_stats AS s
	INNER JOIN sys.indexes AS i ON s.[object_id] = i.[object_id] AND s.index_id = i.index_id
WHERE OBJECTPROPERTY(s.[object_id], 'IsMsShipped') = 0
	AND s.database_id = DB_ID()
	AND (s.user_seeks + s.user_scans + s.user_lookups) > 1
	AND i.[name] IS NOT NULL
ORDER BY usage DESC;